==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2206_162.zip: ronportal/ronportal/elearning/importtestuutils.php <==
<?php
/**
 * UTF8
 * stanislav.elbl, 04.05.2016
 */

namespace RonPortal\ELearning;

use Ron\Personalistika\OtazkaDotazniku;
use Ron\Personalistika\TypOdpovedi;
use Ron\Personalistika\VolbaDotazniku;

require_once('person/dotaznik_otazka.php');


class ImportTestuUtils
{
    /**
     * Import otazek z textu - 1. radek otazka, 2. radek spravna odpoved, pak dalsi odpovedi. Prazdny radek oddeluje otazky
     * @param string $text
     * @return OtazkaDotazniku[]
     */
    public static function nactiImportovaneOtazky($text)
    {
        $result = [];

        $radky = explode("\n", $text);

        $i = 0;

        while ($i < count($radky)) {
            $textOtazky = trim($radky[$i]);
            if ($textOtazky) {
                $otazka = new OtazkaDotazniku(null, null, null);
                $otazka ->f_popis = $textOtazky;
                $otazka ->f_typrozsahu = '_T1zN';
                $otazka ->zpusobHodnoceni = TypOdpovedi::ZPUSOB_ODPOVEDI_VYBER1;
                $otazka ->bodovaVaha = 1;
                $otazka ->povinnaOdpoved = 0;

                $i++;
                $hodnota = 1;

                while ($i < count($radky)  &&  trim($radky[$i])) {
                    $volba = new VolbaDotazniku();
                    $volba ->popis = trim($radky[$i]);
                    $volba ->hodnota = $hodnota;
                    $otazka ->volby[] = $volba;

                    // TODO: umoznit oznacit spravnou odpoved znakem X na zacatku?
                    $i ++;
                    $hodnota ++;
                }

                $result[] = $otazka;
            }

            $i++;
        }

        return $result;
    }


    /**
     * @param \Ron\DB\Database $database
     * @param OtazkaDotazniku[] $otazky
     * @param int $druhHodnoceni
     * @param int $temaCislo
     * @throws \Exception
     */
    public static function importujOtazky($database, $otazky, $druhHodnoceni, $temaCislo, $logDescription)
    {
        foreach($otazky as $otazka) {
            // vlozi otazku
            $kodKriteria = TestyUtils::novyKodOtazkyKTestu($database, $druhHodnoceni, $temaCislo);
            $rec = new OtazkaDBRecord($database, $druhHodnoceni, $temaCislo, $kodKriteria, $kodKriteria, $logDescription);

            $rec ->fPopis ->setNewValue( $otazka ->f_popis );
            $rec ->fUpresnujiciPopis ->setNewValue( $otazka ->f_upresnujicipopis );
            $rec ->fTypRozsahu ->setNewValue( $otazka ->f_typrozsahu );
            $rec ->fBodovaVaha ->setNewValue( $otazka ->bodovaVaha );
            $rec ->fPovinnaOdpoved ->setNewValue( $otazka ->povinnaOdpoved );
            $poradi = OtazkaDBRecord::novePoradi($database, $druhHodnoceni, $temaCislo);
            $rec ->fPoradi ->setNewValue( $poradi );
            // nahodne priradi hodnotu spravne odpovedi
            $spravnaHodnota = rand (1, count($otazka ->volby));
            $rec ->fSpravnaHodnota ->setNewValue($spravnaHodnota);

            $rec ->insertRecord();

            $otazka ->kod = $kodKriteria;
            $otazka ->poradi = $poradi;
            $otazka ->spravnaHodnota = $spravnaHodnota;

            // vlozi odpovedi ----
            $skutecneVolby = [];

            $hodnota = 1;
            $hodnotaOK = false;
            while ( count($otazka ->volby) ) {
                if ($hodnota == $spravnaHodnota) {
                    $index = 0;
                    $hodnotaOK = true;
                } else {
                    $index = rand($hodnotaOK ? 0 : 1, count($otazka ->volby) - 1);
                }

                if ($index >= count($otazka ->volby)) {
                    throw new \Exception('Chyba v metode ImportTestuUtils::importujOtazky!');
                }

                $recVolba = new VycetOdpovediDBRecord($database, $druhHodnoceni, $temaCislo, $kodKriteria, $logDescription);
                $recVolba ->fHodnota ->setNewValue($hodnota);
                $recVolba ->fPopis ->setNewValue( $otazka ->volby[$index] ->popis);
                $recVolba ->insertRecord();

                $otazka ->volby[$index] ->hodnota = $hodnota;
                $skutecneVolby[] = $otazka ->volby[$index];

                array_splice($otazka ->volby, $index, 1);
                $hodnota ++;
            }

            // priradi do otazky skutecne volby vcetne poradi (generuje se z nich json)
            $otazka ->volby = $skutecneVolby;
        }
    }
}

==> helpdesk.ron.cz?menuid=download&filename=ronportal_4_2311_175.zip: ronportal/ronportal/elearning/importtestuutils.php <==
<?php
/**
 * stanislav.elbl, 04.05.2016
 * Zajistuje import otazek z textu
 */

namespace RonPortal\ELearning;

use Ron\DB\Database;
use RonPortal\Testy\OtazkaDotazniku;
use RonPortal\Testy\TypOdpovedi;
use RonPortal\Testy\VolbaDotazniku;


class ImportTestuUtils
{
    /**
     * Import otazek z textu - 1. radek otazka, 2. radek spravna odpoved, pak dalsi odpovedi. Prazdny radek oddeluje otazky
     * @param string $text
     * @return OtazkaDotazniku[]
     */
    public static function nactiImportovaneOtazky($text)
    {
        $result = [];

        $radky = explode("\n", $text);

        $i = 0;

        while ($i < count($radky)) {
            $textOtazky = trim($radky[$i]);
            if ($textOtazky) {
                $otazka = new OtazkaDotazniku(null, null, null);
                $otazka ->f_popis = $textOtazky;
                $otazka ->f_typrozsahu = '_T1zN';
                $otazka ->zpusobHodnoceni = TypOdpovedi::ZPUSOB_ODPOVEDI_VYBER1;
                $otazka ->bodovaVaha = 1;
                $otazka ->povinnaOdpoved = 0;

                $i++;
                $hodnota = 1;

                while ($i < count($radky)  &&  trim($radky[$i])) {
                    $volba = new VolbaDotazniku();
                    $volba ->popis = trim($radky[$i]);
                    $volba ->hodnota = $hodnota;
                    $otazka ->volby[] = $volba;

                    // TODO: umoznit oznacit spravnou odpoved znakem X na zacatku?
                    $i ++;
                    $hodnota ++;
                }

                $result[] = $otazka;
            }

            $i++;
        }

        return $result;
    }


    /**
     * @param Database $database
     * @param OtazkaDotazniku[] $otazky
     * @param int $druhHodnoceni
     * @param int $temaCislo
     * @throws \Exception
     */
    public static function importujOtazky($database, $otazky, $druhHodnoceni, $temaCislo, $logDescription)
    {
        foreach($otazky as $otazka) {
            // vlozi otazku
            $kodKriteria = TestyUtils::novyKodOtazkyKTestu($database, $druhHodnoceni, $temaCislo);
            $rec = new OtazkaDBRecord($database, $druhHodnoceni, $temaCislo, $kodKriteria, $kodKriteria, $logDescription);

            $rec ->fPopis ->setNewValue( $otazka ->f_popis );
            $rec ->fUpresnujiciPopis ->setNewValue( $otazka ->f_upresnujicipopis );
            $rec ->fTypRozsahu ->setNewValue( $otazka ->f_typrozsahu );
            $rec ->fBodovaVaha ->setNewValue( $otazka ->bodovaVaha );
            $rec ->fPovinnaOdpoved ->setNewValue( $otazka ->povinnaOdpoved );
            $poradi = OtazkaDBRecord::novePoradi($database, $druhHodnoceni, $temaCislo);
            $rec ->fPoradi ->setNewValue( $poradi );
            // nahodne priradi hodnotu spravne odpovedi
            $spravnaHodnota = rand (1, count($otazka ->volby));
            $rec ->fSpravnaHodnota ->setNewValue($spravnaHodnota);

            $rec ->insertRecord();

            $otazka ->kod = $kodKriteria;
            $otazka ->poradi = $poradi;
            $otazka ->spravnaHodnota = $spravnaHodnota;

            // vlozi odpovedi ----
            $skutecneVolby = [];

            $hodnota = 1;
            $hodnotaOK = false;
            while ( count($otazka ->volby) ) {
                if ($hodnota == $spravnaHodnota) {
                    $index = 0;
                    $hodnotaOK = true;
                } else {
                    $index = rand($hodnotaOK ? 0 : 1, count($otazka ->volby) - 1);
                }

                if ($index >= count($otazka ->volby)) {
                    throw new \Exception('Chyba v metode ImportTestuUtils::importujOtazky!');
                }

                $recVolba = new VycetOdpovediDBRecord($database, $druhHodnoceni, $temaCislo, $kodKriteria, $logDescription);
                $recVolba ->fHodnota ->setNewValue($hodnota);
                $recVolba ->fPopis ->setNewValue( $otazka ->volby[$index] ->popis);
                $recVolba ->insertRecord();

                $otazka ->volby[$index] ->hodnota = $hodnota;
                $skutecneVolby[] = $otazka ->volby[$index];

                array_splice($otazka ->volby, $index, 1);
                $hodnota ++;
            }

            // priradi do otazky skutecne volby vcetne poradi (generuje se z nich json)
            $otazka ->volby = $skutecneVolby;
        }
    }
}
